@@ -1,5 +1,6 @@
 import sys
 import os
+from importlib import import_module
 
 from scrapy.utils.spider import iter_spider_classes
 from scrapy.command import ScrapyCommand
@@ -15,7 +16,7 @@ def _import_file(filepath):
     if dirname:
         sys.path = [dirname] + sys.path
     try:
-        module = __import__(fname, {}, {}, [''])
+        module = import_module(fname)
     finally:
         if dirname:
             sys.path.pop(0)
@@ -67,7 +68,7 @@ class Command(ScrapyCommand):
             raise UsageError("File not found: %s\n" % filename)
         try:
             module = _import_file(filename)
-        except (ImportError, ValueError), e:
+        except (ImportError, ValueError) as e:
             raise UsageError("Unable to load %r: %s\n" % (filename, e))
         spclasses = list(iter_spider_classes(module))
         if not spclasses:
