@@ -11,7 +11,7 @@ from email.MIMEText import MIMEText
 from email.Utils import COMMASPACE, formatdate
 from email import Encoders
 
-from twisted.internet import defer, reactor
+from twisted.internet import defer, reactor, ssl
 from twisted.mail.smtp import ESMTPSenderFactory
 
 from scrapy import log
@@ -19,18 +19,21 @@ from scrapy import log
 class MailSender(object):
 
     def __init__(self, smtphost='localhost', mailfrom='scrapy@localhost',
-            smtpuser=None, smtppass=None, smtpport=25, debug=False):
+            smtpuser=None, smtppass=None, smtpport=25, smtptls=False, smtpssl=False, debug=False):
         self.smtphost = smtphost
         self.smtpport = smtpport
         self.smtpuser = smtpuser
         self.smtppass = smtppass
+        self.smtptls = smtptls
+        self.smtpssl = smtpssl
         self.mailfrom = mailfrom
         self.debug = debug
 
     @classmethod
     def from_settings(cls, settings):
         return cls(settings['MAIL_HOST'], settings['MAIL_FROM'], settings['MAIL_USER'],
-            settings['MAIL_PASS'], settings.getint('MAIL_PORT'))
+            settings['MAIL_PASS'], settings.getint('MAIL_PORT'),
+            settings.getbool('MAIL_TLS'), settings.getbool('MAIL_SSL'))
 
     def send(self, to, subject, body, cc=None, attachs=(), _callback=None):
         if attachs:
@@ -91,7 +94,12 @@ class MailSender(object):
         d = defer.Deferred()
         factory = ESMTPSenderFactory(self.smtpuser, self.smtppass, self.mailfrom, \
             to_addrs, msg, d, heloFallback=True, requireAuthentication=False, \
-            requireTransportSecurity=False)
+            requireTransportSecurity=self.smtptls)
         factory.noisy = False
-        reactor.connectTCP(self.smtphost, self.smtpport, factory)
+
+        if self.smtpssl:
+            reactor.connectSSL(self.smtphost, self.smtpport, factory, ssl.ClientContextFactory())
+        else:
+            reactor.connectTCP(self.smtphost, self.smtpport, factory)
+
         return d
